Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(696)

Unified Diff: webrtc/modules/remote_bitrate_estimator/include/send_time_history.h

Issue 2710093004: Rename webrtc::PacketInfo to webrtc::PacketFeedback (Closed)
Patch Set: Rebased Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/modules/remote_bitrate_estimator/include/send_time_history.h
diff --git a/webrtc/modules/remote_bitrate_estimator/include/send_time_history.h b/webrtc/modules/remote_bitrate_estimator/include/send_time_history.h
index 2e7259df28df17a2420eb2355aacd7940338a01a..e0ed6bff704ffe39578913ee4082b0ab2f1ccc43 100644
--- a/webrtc/modules/remote_bitrate_estimator/include/send_time_history.h
+++ b/webrtc/modules/remote_bitrate_estimator/include/send_time_history.h
@@ -19,7 +19,7 @@
namespace webrtc {
class Clock;
-struct PacketInfo;
+struct PacketFeedback;
class SendTimeHistory {
public:
@@ -37,16 +37,16 @@ class SendTimeHistory {
// Return false if not found.
bool OnSentPacket(uint16_t sequence_number, int64_t send_time_ms);
// Look up PacketInfo for a sent packet, based on the sequence number, and
// populate all fields except for arrival_time. The packet parameter must
// thus be non-null and have the sequence_number field set.
- bool GetInfo(PacketInfo* packet_info, bool remove);
+ bool GetFeedback(PacketFeedback* packet_feedback, bool remove);
private:
Clock* const clock_;
const int64_t packet_age_limit_ms_;
SequenceNumberUnwrapper seq_num_unwrapper_;
- std::map<int64_t, PacketInfo> history_;
+ std::map<int64_t, PacketFeedback> history_;
RTC_DISALLOW_IMPLICIT_CONSTRUCTORS(SendTimeHistory);
};
@@ -37,16 +37,16 @@ class SendTimeHistory {
// Return false if not found.
bool OnSentPacket(uint16_t sequence_number, int64_t send_time_ms);
- // Look up PacketInfo for a sent packet, based on the sequence number, and
+ // Look up PacketFeedback for a sent packet, based on the sequence number, and
// populate all fields except for arrival_time. The packet parameter must
// thus be non-null and have the sequence_number field set.

Powered by Google App Engine
This is Rietveld 408576698